@@ -10,10 +10,8 @@ def load_to_dicts(yaml_file):
     try:
         return _load_yaml_to_dicts(full_path)
     except FileNotFoundError as e:
-        typer.echo("error: " + str(e))
         typer.echo(f"Could not find {full_path}")
-
-        typer.Exit()
+        raise typer.Exit()
 
 
 def find_file_path_from_module_root(file_name):
